@@ -87,7 +87,7 @@ GeomLode <- ggproto(
     
     # combine polygon grobs
     grob <- do.call(grid::grobTree, polys)
-    grob$name <- grid::grobName(grob, "bar")
+    grob$name <- grid::grobName(grob, "geom_lode")
     grob
   },
   
