@@ -47,7 +47,7 @@ GeomStratum <- ggproto(
   
   required_aes = c("x", "y", "ymin", "ymax"),
   
-  default_aes = aes(size = .5, linetype = 1,
+  default_aes = aes(size = .5, linewidth = .5, linetype = 1,
                     colour = "black", fill = "white", alpha = 1),
   
   setup_data = function(data, params) {
@@ -69,7 +69,7 @@ GeomStratum <- ggproto(
     )
     
     # construct polygon grobs
-    polys <- plyr::alply(data, 1, function(row) {
+    polys <- lapply(split(data, seq_len(nrow(data))), function(row) {
       
       poly <- rect_to_poly(row$xmin, row$xmax, row$ymin, row$ymax)
       aes <- as.data.frame(row[strat_aes],
@@ -80,7 +80,7 @@ GeomStratum <- ggproto(
     
     # combine polygon grobs
     grob <- do.call(grid::grobTree, polys)
-    grob$name <- grid::grobName(grob, "bar")
+    grob$name <- grid::grobName(grob, "geom_stratum")
     grob
   },
   
