@@ -90,6 +90,7 @@ deposit_data <- function(data, decreasing, reverse, absolute) {
 # calculate cumulative 'y' values, accounting for sign
 cumulate <- function(x) {
   if (length(x) == 0) return(x)
+  if (all(x == 0)) return(rep(0, length(x)))
   s <- setdiff(unique(sign(x)), 0)
   stopifnot(length(s) == 1 && s %in% c(-1, 1))
   if (s == 1) {
@@ -100,11 +101,21 @@ cumulate <- function(x) {
 }
 
 # choose a function via the `cement` parameter
+distill_vals <- c("first", "last", "most")
 distill_fun <- function(distill) {
   if (is.function(distill)) {
     return(distill)
-  } else {
+  } else if (distill %in% distill_vals) {
+    return(switch(
+      distill,
+      first = dplyr::first,
+      last = dplyr::last,
+      most = most
+    ))
+  } else if (is.character(distill)) {
     return(get(distill))
+  } else {
+    stop("Please pass either a function or its name to `distill`.")
   }
 }
 
