@@ -1,5 +1,3 @@
-context("geom-lode")
-
 # visual tests
 
 test_that("`geom_lode` draws correctly", {
@@ -7,11 +5,13 @@ test_that("`geom_lode` draws correctly", {
   a1 <- aes(y = Freq, axis = Class)
   a2 <- aes(y = Freq, axis1 = Class, axis2 = Sex, axis3 = Age, fill = Survived)
   
-  vdiffr::expect_doppelganger(
+  skip_on_cran()
+  skip_if_not_installed("vdiffr")
+  suppressWarnings(vdiffr::expect_doppelganger(
     "`geom_lode`: one axis",
     ggplot(d, a1) + geom_lode(aes(fill = Class, alpha = Survived)) +
       scale_x_discrete(limits = c("Class"))
-  )
+  ))
   vdiffr::expect_doppelganger(
     "`geom_lode`: lodes and alluvia",
     ggplot(d, a2) + geom_alluvium() + geom_lode()
